function D=cc2dam_lene(cc,m,loga,stresslim,tref,thk,k)
% Copied from
% Calculates the total Palmgren-Miner damage of a cycle count.
% (two-slope SN curve)
% 
% CALL: D = cc2dam_lene(cc,beta,K,stresslim,thk,tref,k);
% 
%   D    = Damage.                                                     [1]
%
%   cc   = Cycle count with minima in column 1 and                    [nx2]
%          maxima in column 2. (MPa)
%   m   = m-values, material parameter.                           [1x2]
%   loga    = log(a)-values, material parameter.      [1x2]
%   stresslim = stress limit for first value of beta and K             [1]
%     (Optional, Default: 0)
%   thk  = cross-section thickness (m)  (Optional, Default: 0.25)      [1]
%   tref = reference thickness (m)      (Optional, Default: 0.25)      [1]      
%   k    = exponent for the thickness factor (Optional, Default: 0.0)  [1]
%   cc - cycle count with minima in column 1 and maxima in column 2 [MPa]
 
% Calculate damage

if (thk < tref)
    thk = tref;
end

% amplitudes
amp = abs(cc(:,2)-cc(:,1))/2;

% sum over amplitudes
n=length(amp);
Di=zeros(1,n);
D = 0;
% for loop over number of amplitudes
% ii - counter for amplitudes
for ii=1:n
    ampi = amp(ii);
    if ampi>stresslim/2 % few cycles 
        % note that the input stresslim is for stress ranges
        % here we are dealing with stress amplitudes
        a=1/(10^loga(1));
        mi = m(1);
        fac1 = (2^(mi));
        fac2 = (thk/tref)^(k*mi);
        Ki  = a*fac1*fac2;
    else % many cycles
        a=1/(10^loga(2));
        mi = m(2);
        fac1 = (2^(mi));
        fac2 = (thk/tref)^(k*mi);
        Ki  = a*fac1*fac2;
    end
      D = D + Ki*(ampi^mi);
      Di(ii)=Ki*ampi^mi;
end